@@ -1,8 +1,11 @@
 import logging
 import optparse
+import os
 import signal
 import sys
-import time
+
+import gobject
+gobject.threads_init()
 
 # Extract any non-GStreamer arguments, and leave the GStreamer arguments for
 # processing by GStreamer. This needs to be done before GStreamer is imported,
@@ -18,30 +21,30 @@ sys.argv[1:] = gstreamer_args
 from pykka.registry import ActorRegistry
 
 from mopidy import (get_version, settings, OptionalDependencyError,
-    SettingsError)
+    SettingsError, DATA_PATH, SETTINGS_PATH, SETTINGS_FILE)
 from mopidy.gstreamer import GStreamer
 from mopidy.utils import get_class
 from mopidy.utils.log import setup_logging
 from mopidy.utils.path import get_or_create_folder, get_or_create_file
-from mopidy.utils.process import (GObjectEventThread, exit_handler,
-    stop_all_actors)
+from mopidy.utils.process import (exit_handler, stop_remaining_actors,
+    stop_actors_by_class)
 from mopidy.utils.settings import list_settings_optparse_callback
 
 logger = logging.getLogger('mopidy.core')
 
 def main():
     signal.signal(signal.SIGTERM, exit_handler)
+    loop = gobject.MainLoop()
     try:
         options = parse_options()
         setup_logging(options.verbosity_level, options.save_debug_log)
+        check_old_folders()
         setup_settings(options.interactive)
-        setup_gobject_loop()
         setup_gstreamer()
         setup_mixer()
         setup_backend()
         setup_frontends()
-        while True:
-            time.sleep(1)
+        loop.run()
     except SettingsError as e:
         logger.error(e.message)
     except KeyboardInterrupt:
@@ -49,7 +52,12 @@ def main():
     except Exception as e:
         logger.exception(e)
     finally:
-        stop_all_actors()
+        loop.quit()
+        stop_frontends()
+        stop_backend()
+        stop_mixer()
+        stop_gstreamer()
+        stop_remaining_actors()
 
 def parse_options():
     parser = optparse.OptionParser(version=u'Mopidy %s' % get_version())
@@ -58,12 +66,12 @@ def parse_options():
         help='show GStreamer help options')
     parser.add_option('-i', '--interactive',
         action='store_true', dest='interactive',
-        help='ask interactively for required settings which is missing')
+        help='ask interactively for required settings which are missing')
     parser.add_option('-q', '--quiet',
         action='store_const', const=0, dest='verbosity_level',
         help='less output (warning level)')
     parser.add_option('-v', '--verbose',
-        action='store_const', const=2, dest='verbosity_level',
+        action='count', default=1, dest='verbosity_level',
         help='more output (debug level)')
     parser.add_option('--save-debug-log',
         action='store_true', dest='save_debug_log',
@@ -73,30 +81,54 @@ def parse_options():
         help='list current settings')
     return parser.parse_args(args=mopidy_args)[0]
 
+def check_old_folders():
+    old_settings_folder = os.path.expanduser(u'~/.mopidy')
+
+    if not os.path.isdir(old_settings_folder):
+        return
+
+    logger.warning(u'Old settings folder found at %s, settings.py should be '
+        'moved to %s, any cache data should be deleted. See release notes '
+        'for further instructions.', old_settings_folder, SETTINGS_PATH)
+
 def setup_settings(interactive):
-    get_or_create_folder('~/.mopidy/')
-    get_or_create_file('~/.mopidy/settings.py')
+    get_or_create_folder(SETTINGS_PATH)
+    get_or_create_folder(DATA_PATH)
+    get_or_create_file(SETTINGS_FILE)
     try:
         settings.validate(interactive)
     except SettingsError, e:
         logger.error(e.message)
         sys.exit(1)
 
-def setup_gobject_loop():
-    GObjectEventThread().start()
-
 def setup_gstreamer():
     GStreamer.start()
 
+def stop_gstreamer():
+    stop_actors_by_class(GStreamer)
+
 def setup_mixer():
     get_class(settings.MIXER).start()
 
+def stop_mixer():
+    stop_actors_by_class(get_class(settings.MIXER))
+
 def setup_backend():
     get_class(settings.BACKENDS[0]).start()
 
+def stop_backend():
+    stop_actors_by_class(get_class(settings.BACKENDS[0]))
+
 def setup_frontends():
     for frontend_class_name in settings.FRONTENDS:
         try:
             get_class(frontend_class_name).start()
         except OptionalDependencyError as e:
             logger.info(u'Disabled: %s (%s)', frontend_class_name, e)
+
+def stop_frontends():
+    for frontend_class_name in settings.FRONTENDS:
+        try:
+            stop_actors_by_class(get_class(frontend_class_name))
+        except OptionalDependencyError:
+            pass
