@@ -16,48 +16,34 @@ def translator(data):
     artist_kwargs = {}
     track_kwargs = {}
 
-    # FIXME replace with data.get('foo', None) ?
+    def _retrieve(source_key, target_key, target):
+        if source_key in data:
+            target[target_key] = data[source_key]
 
-    if 'album' in data:
-        album_kwargs['name'] = data['album']
+    _retrieve(gst.TAG_ALBUM, 'name', album_kwargs)
+    _retrieve(gst.TAG_TRACK_COUNT, 'num_tracks', album_kwargs)
+    _retrieve(gst.TAG_ARTIST, 'name', artist_kwargs)
 
-    if 'track-count' in data:
-        album_kwargs['num_tracks'] = data['track-count']
-
-    if 'artist' in data:
-        artist_kwargs['name'] = data['artist']
-
-    if 'date' in data:
-        date = data['date']
+    if gst.TAG_DATE in data and data[gst.TAG_DATE]:
+        date = data[gst.TAG_DATE]
         date = datetime.date(date.year, date.month, date.day)
         track_kwargs['date'] = date
 
-    if 'title' in data:
-        track_kwargs['name'] = data['title']
+    _retrieve(gst.TAG_TITLE, 'name', track_kwargs)
+    _retrieve(gst.TAG_TRACK_NUMBER, 'track_no', track_kwargs)
 
-    if 'track-number' in data:
-        track_kwargs['track_no'] = data['track-number']
-
-    if 'album-artist' in data:
-        albumartist_kwargs['name'] = data['album-artist']
-
-    if 'musicbrainz-trackid' in data:
-        track_kwargs['musicbrainz_id'] = data['musicbrainz-trackid']
-
-    if 'musicbrainz-artistid' in data:
-        artist_kwargs['musicbrainz_id'] = data['musicbrainz-artistid']
-
-    if 'musicbrainz-albumid' in data:
-        album_kwargs['musicbrainz_id'] = data['musicbrainz-albumid']
-
-    if 'musicbrainz-albumartistid' in data:
-        albumartist_kwargs['musicbrainz_id'] = data['musicbrainz-albumartistid']
+    # Following keys don't seem to have TAG_* constant.
+    _retrieve('album-artist', 'name', albumartist_kwargs)
+    _retrieve('musicbrainz-trackid', 'musicbrainz_id', track_kwargs)
+    _retrieve('musicbrainz-artistid', 'musicbrainz_id', artist_kwargs)
+    _retrieve('musicbrainz-albumid', 'musicbrainz_id', album_kwargs)
+    _retrieve('musicbrainz-albumartistid', 'musicbrainz_id', albumartist_kwargs)
 
     if albumartist_kwargs:
         album_kwargs['artists'] = [Artist(**albumartist_kwargs)]
 
     track_kwargs['uri'] = data['uri']
-    track_kwargs['length'] = data['duration']
+    track_kwargs['length'] = data[gst.TAG_DURATION]
     track_kwargs['album'] = Album(**album_kwargs)
     track_kwargs['artists'] = [Artist(**artist_kwargs)]
 
@@ -71,17 +57,16 @@ class Scanner(object):
         self.error_callback = error_callback
         self.loop = gobject.MainLoop()
 
-        caps = gst.Caps('audio/x-raw-int')
         fakesink = gst.element_factory_make('fakesink')
-        pad = fakesink.get_pad('sink')
 
         self.uribin = gst.element_factory_make('uridecodebin')
-        self.uribin.connect('pad-added', self.process_new_pad, pad)
-        self.uribin.set_property('caps', caps)
+        self.uribin.set_property('caps', gst.Caps('audio/x-raw-int'))
+        self.uribin.connect('pad-added', self.process_new_pad,
+            fakesink.get_pad('sink'))
 
         self.pipe = gst.element_factory_make('pipeline')
-        self.pipe.add(fakesink)
         self.pipe.add(self.uribin)
+        self.pipe.add(fakesink)
 
         bus = self.pipe.get_bus()
         bus.add_signal_watch()
@@ -92,22 +77,36 @@ class Scanner(object):
         pad.link(target_pad)
 
     def process_tags(self, bus, message):
-        data = message.parse_tag()
-        data = dict([(k, data[k]) for k in data.keys()])
-        data['uri'] = unicode(self.uribin.get_property('uri'))
-        data['duration'] = self.get_duration()
-        self.data_callback(data)
-        self.next_uri()
+        taglist = message.parse_tag()
+        data = {
+            'uri': unicode(self.uribin.get_property('uri')),
+            gst.TAG_DURATION: self.get_duration(),
+        }
+
+        for key in taglist.keys():
+            # XXX: For some crazy reason some wma files spit out lists here,
+            # not sure if this is due to better data in headers or wma being
+            # stupid. So ugly hack for now :/
+            if type(taglist[key]) is list:
+                data[key] = taglist[key][0]
+            else:
+                data[key] = taglist[key]
+
+        try:
+            self.data_callback(data)
+            self.next_uri()
+        except KeyboardInterrupt:
+            self.stop()
 
     def process_error(self, bus, message):
         if self.error_callback:
             uri = self.uribin.get_property('uri')
-            errors = message.parse_error()
-            self.error_callback(uri, errors)
+            error, debug = message.parse_error()
+            self.error_callback(uri, error, debug)
         self.next_uri()
 
     def get_duration(self):
-        self.pipe.get_state()
+        self.pipe.get_state() # Block until state change is done.
         try:
             return self.pipe.query_duration(
                 gst.FORMAT_TIME, None)[0] // gst.MSECOND
