@@ -1,8 +1,10 @@
 from distutils.version import StrictVersion as SV
-import unittest
 import platform
 
-from mopidy import get_version, get_plain_version, get_platform, get_python
+from mopidy import get_plain_version, get_platform, get_python
+
+from tests import unittest
+
 
 class VersionTest(unittest.TestCase):
     def test_current_version_is_parsable_as_a_strict_version_number(self):
@@ -19,8 +21,9 @@ class VersionTest(unittest.TestCase):
         self.assert_(SV('0.3.0') < SV('0.3.1'))
         self.assert_(SV('0.3.1') < SV('0.4.0'))
         self.assert_(SV('0.4.0') < SV('0.4.1'))
-        self.assert_(SV('0.4.1') < SV(get_plain_version()))
-        self.assert_(SV(get_plain_version()) < SV('0.5.1'))
+        self.assert_(SV('0.4.1') < SV('0.5.0'))
+        self.assert_(SV('0.5.0') < SV(get_plain_version()))
+        self.assert_(SV(get_plain_version()) < SV('0.6.1'))
 
     def test_get_platform_contains_platform(self):
         self.assert_(platform.platform() in get_platform())
